==> tabler-2.2.1.tar.gz: tabler-2.2.1/tabler/tabletypes/ods.py <==
"""This module provides a Table Type for Open Document Format (.ods) files."""

import ezodf
import odswriter

from .basetabletype import BaseTableType


class ODS(BaseTableType):
    """Table Type for Open Document Format (.ods) files.

    :param str extension: Extension of file to save. Default .ods.
    :param verbose: If True print status messages. If None use
        :class:`tabler.tabletype.BaseTableType`.verbose.
    :type verbose: bool or None.
    """

    extensions = ['.ods']

    def __init__(self, sheet=0, extension='.ods', verbose=True):
        """Consturct :class:`tabler.tabletypes.ODS`.

        :param str extension: Extension of file to save. Default .ods.
        :param verbose: If True print status messages. If None use
            :class:`tabler.tabletype.BaseTableType`.verbose.
        :type verbose: bool or None.
        """
        self.sheet = sheet
        super().__init__(extension, verbose=verbose)

    def open(self, path):
        """Return header and rows from file.

        :param path: Path to file to be opened.
        :type path: str, pathlib.Path or compatible.
        """
        doc = ezodf.opendoc(path)
        sheet = doc.sheets[self.sheet]
        rows = []
        for row in sheet:
            new_row = []
            for cell in row:
                if cell.value is not None:
                    new_row.append(cell.value)
                else:
                    new_row.append('')
            if len(row) > 0:
                rows.append(new_row)
        return rows[0], rows[1:]

    def write(self, table, path):
        """Save data from :class:`tabler.Table` to file.

        :param table: Table to save.
        :type table: :class:`tabler.Table`
        :param path: Path to file to be opened.
        :type path: str, pathlib.Path or compatible.
        """
        with odswriter.writer(open(path, 'wb')) as odsfile:
            for row in table:
                odsfile.writerow(table.header)
                odsfile.writerow(row)
        print('Written {} rows to file {}'.format(len(table.rows), path))

==> tabler-2.4.0.tar.gz: tabler-2.4.0/tabler/tabletypes/ods.py <==
"""This module provides a Table Type for Open Document Format (.ods) files."""

import sys

import pyexcel_ods

from .basetabletype import BaseTableType


class ODS(BaseTableType):
    """Table Type for Open Document Format (.ods) files.

    :param str extension: Extension of file to save. Default .ods.
    :param verbose: If True print status messages. If None use
        :class:`tabler.tabletype.BaseTableType`.verbose.
    :type verbose: bool or None.
    """

    extensions = [".ods"]
    empty_value = ""

    def __init__(self, sheet=0, extension=".ods", verbose=True):
        """Consturct :class:`tabler.tabletypes.ODS`.

        :param str extension: Extension of file to save. Default .ods.
        :param verbose: If True print status messages. If None use
            :class:`tabler.tabletype.BaseTableType`.verbose.
        :type verbose: bool or None.
        """
        self.sheet = sheet
        super().__init__(extension, verbose=verbose)

    def open_path(self, path):
        """Return header and rows from file.

        :param path: Path to file to be opened.
        :type path: str, pathlib.Path or compatible.
        """
        data = pyexcel_ods.get_data(str(path))
        sheet = data[list(data.keys())[self.sheet]]
        return self.parse_row_data(sheet)

    def write(self, table, path):
        """Save data from :class:`tabler.Table` to file.

        :param table: Table to save.
        :type table: :class:`tabler.Table`
        :param path: Path to file to be opened.
        :type path: str, pathlib.Path or compatible.
        """
        rows = self.prepare_rows(table.header, [list(_) for _ in table.rows])
        sheets = {"Sheet {}".format(self.sheet): rows}
        pyexcel_ods.save_data(str(path), sheets)
        print(
            "Written {} rows to file {}".format(len(table.rows), path), file=sys.stderr
        )
